@echo off
rem -------------------------------------------------------------------------------
rem Configure WebSphere MQ permissions Script
rem
rem Arguments: -g queueManagerName RITEntity puttingApplicationEntity stubbedQueueName responseQueueName
rem
rem -g
rem          Group mode. Set permissions for groups instead of users. 
rem          Defaults to setting permissions for users. (Optional)
rem queueManagerName
rem          The name of the local queue manager to configure permissions for.
rem RITEntity
rem          The user ID configured in the physical resources in
rem          Rational Integration Tester or, the name of a group that the user belongs
rem          to.
rem puttingApplicationEntity
rem          The user ID used by the existing application putting messages onto MQ queues or,
rem          the name of a group that the user belongs to.
rem stubbedQueueName
rem          The name of the queue that the Stub will be reading messages from.
rem responseQueueName
rem          The name of the queue that stubbed messages should be placed onto. (Optional)
rem -------------------------------------------------------------------------------

setlocal

rem ---- Check to see whether we should apply permissions for users or groups
rem      Defaults to users ----
SET entityType=-p

if "%1"=="-g" (
    SET entityType=-g
    SHIFT
)

rem ---- Check to see if a response queue has been set ----
if "x%5x" NEQ "xx" (
	SET responseQueue=%5
	SHIFT /5
)

if "x%4x" == "xx" goto PrintUsage
if "x%5x" NEQ "xx" goto PrintUsage

rem Dump all existing queue manager authorities to file prior to running the setmqaut commands
dmpmqaut -m %1 > preSiftAndPassThroughAuthorityBackup.aut 2>&1

rem ---- Set permissions to enable access for the MQ user configured in RIT ----
setmqaut -m %1 -t qmgr %entityType% "%2" +connect +inq +dsp +setall
setmqaut -m %1 -n "rit.divert.rules*" -t namelist %entityType% "%2" +chg +inq +dsp
setmqaut -m %1 -n %4 -t q %entityType% "%2" +put +setall
setmqaut -m %1 -n SYSTEM.DURABLE.MODEL.QUEUE -t q %entityType% "%2" +get +dsp
setmqaut -m %1 -n SYSTEM.ADMIN.COMMAND.QUEUE -t q %entityType% "%2" +put +inq
setmqaut -m %1 -n SYSTEM.DEFAULT.MODEL.QUEUE -t q %entityType% "%2" +get +dsp
setmqaut -m %1 -n SYSTEM.DEFAULT.NAMELIST -t namelist %entityType% "%2" +dsp
setmqaut -m %1 -n "**" -t namelist %entityType% "%2" +crt
IF DEFINED responseQueue (
    setmqaut -m %1 -n "%responseQueue%" -t q %entityType% "%2" +put
)

rem ---- Set permissions to enable access for the MQ user used by the existing application ----
setmqaut -m %1 -t qmgr %entityType% "%3" +connect +inq
setmqaut -m %1 -n "rit.divert.rules*" -t namelist %entityType% "%3" +inq
setmqaut -m %1 -n "AMQ.RIT.DIVERTED.**" -t q %entityType% "%3" +get +put
setmqaut -m %1 -n "AMQ.RIT.STUB.**" -t q %entityType% "%3" +put

goto End

:PrintUsage
echo arguments: [-g] queueManagerName RITEntity puttingApplicationEntity stubbedQueueName [responseQueueName]
echo -g
echo    Group mode. Set permissions for groups instead of users. 
echo    Defaults to setting permissions for users. (Optional)
echo.
echo queueManagerName
echo    The name of the local queue manager to configure permissions for.
echo.
echo RITEntity
echo    The user ID configured in the physical resource in Rational Integration Tester or, the name of a group that the user belongs to.
echo.
echo puttingApplicationEntity
echo    The user ID used by the existing application putting messages onto MQ queues or, the name of a group that the user belongs to.
echo.
echo stubbedQueueName
echo    The name of the queue that the Stub will be reading messages from
echo.
echo responseQueueName
echo    The name of the queue that stubbed messages should be placed onto. (Optional)

:End

endlocal